
function [H1,L1,alpha1] = shoal_waves(H0,h0,alpha0,T,h1)
    %shoal.m shoals surface gravity waves to a different water depth
    %H0 [meters] given wave height
    %h0 [meters] given water depth
    %alpha0 [deg] given angle rel. to shore normal
    %T [sec] wave period
    %h1 [meters]  depth where characteristics are sought
    %
    [alpha1] = snells(alpha0,h0,T,h1);
    [k,n0,c0] = dispersion (2*pi./T,h0);
    [k,n1,c1] = dispersion (2*pi./T,h1);
    L1 = 2*pi./k;
    H1 = H0.*sqrt((c0.*n0)./(c1.*n1)).*sqrt(cos(alpha0*pi/180)./cos(alpha1*pi/180));

end

function [alpha] = snells(alpha0,h0,T,d)
    %snells.m usings Snells law to determine wave direction changes
    %Calculate the changing angle due to refraction for the 
    % case of straight parallel contours for monchromatic wave
    % alpha0[deg]
    % h0[m]
    % T[s]
    % d [m] matrix or array of depths from which to find angles
    % alpha [deg] is matrix or array of angles with size(alpha)=size(d) 
    % function [alpha] = snells(alpha0,h0,T,d)
    omega = 2*pi./T;
    [k0] = dispersion (omega,h0);c0 = omega./k0;
    [k] = dispersion (omega,d);c = omega./k;
    alpha = real(180/pi*asin(sin(alpha0*pi/180).*c./c0));

end
  
function [k,n,c] = dispersion (w,h,showflag)
    % dispersion solves the linear dispersion relation
    % given frequency, w = 2 pi/Period [1/sec], 
    % and water depth, h [meters] the dispersion routine returns the 
    % wavenumber, k = 2 pi/Wavelength [1/m],
    % n = ratio of group speed to phase speed, and 
    % c = phase speed [m/s]
    % [k n c] = dispersion (w,h)
    % function [k,n,c] = dispersion (w,h,showflag)

    if nargin<3;showflag = 1;end
    if find(h<=0)>0&showflag;
      %  disp('WARNING: water depth should be > 0');
      %  disp('A wavenumber of 10^10 will be returned for all depths <= 0  ');
    end
    ind = find(h<=0);h(ind)= 1;
    g = 9.81;
    k=w./sqrt(g*h);diff=max(max(w.^2-g*k.*tanh(k.*h)));
    while abs(diff) > 1*10^-8
      knew = k -(w.^2-g*k.*tanh(k.*h))./(-g*tanh(k.*h)-g*k.*h.*sech(k.*h).^2);
      k = knew;
      diff=max(max(w.^2-g*k.*tanh(k.*h)));
    end
    c=w./k;
    k(ind) = 10^10;
    n = .5*(1+(2*k.*h)./sinh(2*k.*h));
    n(ind) = 1;
    c(ind) = 0;
end